
/* 
 *  @(#)play.c 02/01/23 1.2 SMI
 *
 *  Copyright (c) 1989-2002, Sun Microsystems, Inc.
 */

#include <stdio.h>
#include <unistd.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/wait.h>

#define EXECVP   (void) execvp
#define FPRINTF  (void) fprintf
#define SIGNAL   (void) signal


/* Play a list of audio files by exec'ing an external audio play program. */

void
playit(char *progname, char **argv)
{
    pid_t child;
    int exec_errno = 0;
    int status;

    child = vfork(); 
    if (child == -1) {
        FPRINTF(stderr, "%s: cannot fork audio program.\n", progname);
        exit(1);
    }
    if (child == 0) { 
        EXECVP(argv[0], &argv[0]); 
        exec_errno = errno; 
        exit(127); 
    } 
    while (waitpid(child, &status, WEXITED) != child) {
        continue; 
    }

    if (WIFEXITED(status)) {
        if (WEXITSTATUS(status) != 0) {
            if (exec_errno != 0) {
                errno = exec_errno;
                FPRINTF(stderr, "%s: could not execute %s", progname, argv[0]);
                exit(1);
            }
            FPRINTF(stderr, "%s: warning: %s exited with code %d\n",
                    progname, argv[0], WEXITSTATUS(status));
        }
    } else {
        FPRINTF(stderr, "%s: warning: %s died on signal %d\n",
                progname, argv[0], WTERMSIG(status));
    }
}
